==> jc-1.4.0.tar.gz: soot/jimple/toolkits/annotation/arraycheck/FlowGraphEdge.h <==
// class soot.jimple.toolkits.annotation.arraycheck.FlowGraphEdge

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 818e293d06cb1a94 soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge_H_
#define _JC_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$sub_refs	_jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$sub_refs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$sub_nonrefs	_jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$refs	_jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$refs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$nonrefs	_jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$object	_jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$object;

typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$vmethods	_jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$vmethods;
typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$vtable	_jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$vtable;
typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$vtype	_jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$object *);
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$method$_init$1b34a4ef37055d19(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);

// Virtual methods
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$method$changeEndUnits$b90e1e7220decec3(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
extern jboolean _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$method$equals$8a15e0625571c581(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$method$getStartUnit$c07df75e3ea5693d(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$method$getTargetUnit$872d015bc2ed51c9(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$object *);
extern jint _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$method$hashCode$53152098849316df(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$method_info$changeEndUnits$b90e1e7220decec3;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$method_info$getStartUnit$c07df75e3ea5693d;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$method_info$getTargetUnit$872d015bc2ed51c9;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$vmethods {
	void	(*changeEndUnits$b90e1e7220decec3)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Object$object	*(*getStartUnit$c07df75e3ea5693d)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$object *);
	struct _jc_java_lang_Object$object	*(*getTargetUnit$872d015bc2ed51c9)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$vmethods	soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge;
};

// Vtype
struct _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$sub_refs {
	struct _jc_java_lang_Object$object	*from;
	struct _jc_java_lang_Object$object	*to;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$refs {
    _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$sub_refs	soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$sub_nonrefs	soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$object {
	_jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$vtype	*vtype;
	_jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$vtype _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$class_object;

#endif	/* _JC_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/annotation/arraycheck/FlowGraphEdge.h <==
// class soot.jimple.toolkits.annotation.arraycheck.FlowGraphEdge

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 818e293d06cb1a94 soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge_H_
#define _JC_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$sub_refs	_jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$sub_refs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$sub_nonrefs	_jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$refs	_jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$refs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$nonrefs	_jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$object	_jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$object;

typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$vmethods	_jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$vmethods;
typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$vtable	_jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$vtable;
typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$vtype	_jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$method$_init$1b34a4ef37055d19(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$method$changeEndUnits$b90e1e7220decec3(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$method$equals$8a15e0625571c581(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$method$getStartUnit$c07df75e3ea5693d(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$method$getTargetUnit$872d015bc2ed51c9(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$method$hashCode$53152098849316df(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$method_info$changeEndUnits$b90e1e7220decec3;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$method_info$getStartUnit$c07df75e3ea5693d;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$method_info$getTargetUnit$872d015bc2ed51c9;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$vmethods {
	void	(*changeEndUnits$b90e1e7220decec3)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*getStartUnit$c07df75e3ea5693d)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*getTargetUnit$872d015bc2ed51c9)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$vmethods	soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge;
};

// Vtype
struct _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$sub_refs {
	struct _jc_java_lang_Object$object	*from;
	struct _jc_java_lang_Object$object	*to;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$refs {
    _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$sub_refs	soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$sub_nonrefs	soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$object {
	_jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$vtype	*vtype;
	_jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$vtype _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge$class_object;

#endif	/* _JC_soot_jimple_toolkits_annotation_arraycheck_FlowGraphEdge_H_ */
